<?php
//バリデーションクラス

class InquiryValidator {

	//必須チェック
	static protected function required($str) {
		$str = trim($str);
		if ($str != "") {
			return true;
		}
		return false;
	}
	
	//半角数字チェック
	static protected function isNumber($str) {
		if (preg_match("/^[0-9]+$/", $str)) {
    		return true;
		}
		return false;
	}
	
	//半角英字チェック
	static protected function isAlpha($str) {
		if (preg_match("/^[a-zA-Z]+$/", $str)) {
			return true;
		}
		return false;
	}
	
	//半角英数字チェック
	static protected function isHankaku($str) {
		if (preg_match("/^[a-zA-Z0-9]+$/", $str)) {
			return true;
		}
		return false;
	}
	
	//全角チェック
	static protected function isZenkaku($str) {
		if( preg_match( "/^[\x81-\xFC]+$/", $str ) ) {
			return true;
		} else {
			return false;
		}
	}
	
	//最大長チェック
	static protected function maxlength($str, $max) {
		$str = mb_convert_encoding($str, "UTF-8", "auto");
		if (mb_strlen($str, 'UTF-8') <= $max) {
			return true;
		}
		return false;
	}
	
	//メールアドレスチェック
	static protected function check_mail($str, $mode = '') {
		if ($mode == '' && preg_match("/^[!-~]+@[!-~]+$/", $str)) {
			return true;
		} elseif ($mode == 'NOTRFC' && preg_match('/^([\w])+([\w\._-])*\@([\w])+([\w\._-])*\.([a-zA-Z])+$/', $str)) {
			return true;
		} elseif ($mode == 'RFC' && preg_match('/^(?:[^(\040)<>@,;:".\\\\\[\]\000-\037\x80-\xff]+(?![^(\040)<>@,;:".\\\\\[\]\000-\037\x80-\xff])|"[^\\\\\x80-\xff\n\015"]*(?:\\\\[^\x80-\xff][^\\\\\x80-\xff\n\015"]*)*")(?:\.(?:[^(\040)<>@,;:".\\\\\[\]\000-\037\x80-\xff]+(?![^(\040)<>@,;:".\\\\\[\]\000-\037\x80-\xff])|"[^\\\\\x80-\xff\n\015"]*(?:\\\\[^\x80-\xff][^\\\\\x80-\xff\n\015"]*)*"))*@(?:[^(\040)<>@,;:".\\\\\[\]\000-\037\x80-\xff]+(?![^(\040)<>@,;:".\\\\\[\]\000-\037\x80-\xff])|\[(?:[^\\\\\x80-\xff\n\015\[\]]|\\\\[^\x80-\xff])*\])(?:\.(?:[^(\040)<>@,;:".\\\\\[\]\000-\037\x80-\xff]+(?![^(\040)<>@,;:".\\\\\[\]\000-\037\x80-\xff])|\[(?:[^\\\\\x80-\xff\n\015\[\]]|\\\\[^\x80-\xff])*\]))*$/', $str)) {
			return true;
		}
		return false;
	}
	
	//メールアドレスのドメイン部レコードの確認
	static protected function check_dns_record($str, $mode="") {
		if ($mode!="" && self::check_mail($str)) {
			$mail = explode('@', $str);
			return checkdnsrr($mail[1], $mode);
		}
		return false;
	}
	
	//配列と一致すればエラー
	static protected function check_list( $str, $list=array() ) {
		$flg = true;
		foreach($list as $val) {
			if ($val === $str) {
				$flg = false;
				break;
			}
		}
		return $flg;
	}
	
	//確認用フォームのチェック
	static protected function check_confirm( $str, $target ) {
		if ($str === $target) {
			return true;
		}
		return false;
	}
	
	//携帯電話番号チェック
	static protected function is_mobile_easy( $str ) {
		if( preg_match( "/^0[57-9]0\d{4}\d{4}$/", $str ) ) {
			return ture;
		}
		return false;
	}
	
	//携帯電話番号チェック
	static protected function is_mobile_exact( $str1, $str2, $str3 ) {
		$str = $str1.'-'.$str2.'-'.$str3;
		if( preg_match( "/^0[57-9]0-\d{4}-\d{4}$/", $str ) ) {
			return ture;
		}
		return false;
	}
	
	//固定電話チェック
	static protected function is_phone_easy( $str ) {
		if( preg_match( "/^0\d{9}$/", $str ) ) {
			return ture;
		}
		return false;
	}
	
	//固定電話チェック
	static protected function is_phone_exact( $str1, $str2, $str3 ) {
		$str = $str1.'-'.$str2.'-'.$str3;
		if( preg_match( "/^(0(?:[1-9]|[1-9]{2}\d{0,2}))-([2-9]\d{0,3})-(\d{4})$/", $str ) && strlen($str) == 12 ) {
			return ture;
		}
		return false;
	}
}


class InquiryValidatorMessage {
	const REQUIRED         = 'が入力されていません';
	const REQUIRED_SELECT  = 'が選択されていません';
	const MAXLENGTH        = 'は__maxlength__文字以下で入力してください';
	const HANKAKU          = 'は半角英数字で入力してください';
	const EIJI             = 'は半角英字で入力してください';
	const NUMBER           = 'は半角数字で入力してください';
	const ZENKAKU          = 'は全角で入力してください';
	const KEISHIKI         = 'の形式が正しくありません';
	const BANNED           = 'に__banned__は指定できません';
	const CONFIRM          = '(確認用)と一致しません';
}
